pub struct Message {
pub role: Role,
pub content: String,
pub timestamp: DateTime<Utc>,
/* private fields */
}Fields
role: Rolecontent: Stringtimestamp: DateTime<Utc>Implementations
Sourceimpl Message
impl Message
pub fn code_blocks(&self) -> Vec<&CodeBlock>
pub fn non_code_content(&self) -> &str
pub fn new(role: Role, content: &str, timestamp: DateTime<Utc>) -> Self
pub fn new_user(text: &str) -> Self
pub fn new_asst(text: &str) -> Self
pub fn update(&mut self, text: &str)
pub fn new_from_db(role: Role, content: String, timestamp_epoch: f64) -> Self
pub fn timestamp_epoch(&self) -> f64
pub fn timestamp_millis(&self) -> i64
pub fn is_user(&self) -> bool
pub fn is_assistant(&self) -> bool
pub fn is_system(&self) -> bool
Sourcepub fn formatted_content<'a>(
&'a self,
index: &mut usize,
line_width: u16,
) -> Text<'a>
pub fn formatted_content<'a>( &'a self, index: &mut usize, line_width: u16, ) -> Text<'a>
Get the text for this message as it will be displayed, with highlights and annotations
index is the value to start numbering the block annotations from
Sourcepub fn update_blocks(&mut self)
pub fn update_blocks(&mut self)
update code_blocks and non_code_content to align with the message text